pub enum TraitItem {
Const(TraitItemConst),
Fn(TraitItemFn),
Type(TraitItemType),
Reft(TraitItemReft),
}Variants
Const(TraitItemConst)
An associated constant within the definition of a trait.
Fn(TraitItemFn)
An associated function within the definition of a trait.
Type(TraitItemType)
An associated type within the definition of a trait.
Reft(TraitItemReft)
An associated refinements within the definition of a trait.